#pragma once

namespace map
{

namespace algorithm
{

// This reloads all models in the map
void refreshModels(bool blockScreenUpdates);

// This reloads all selected models in the map
void refreshSelectedModels(bool blockScreenUpdates);

}

}

